# KH2Randomizer

[Website](https://tommadness.github.io/KH2Randomizer/)

![Screenshot of the seed generator user interface](docs/seed-generator-screenshot.png)

## Acknowledgements

Icons and font by Televo

Special thanks to Sonicshadowsilver2 for the creation of the Garden of Assemblage mod, 1234567890num for helping bring
it to PC, and Bizkit047, Valaxor, and Desa3579 for the original Randomizer

Special thanks to Xeeynamo and the OpenKH team for their reverse engineering effort and the OpenKH Mods Manager, both of
which makes this all possible.
